/**
 * {头像组件}
 * @author yutent<yutent.io@gmail.com>
 * @date 2023/04/25 09:27:25
 */
import { html, css, Component } from 'wkit'
import '../base/icon.js'

class Avatar extends Component {
  static props = {
    src: {
      type: String,
      default: null
    }
  }

  static styles = [
    css`
      :host {
        display: inline-flex;
        width: 32px;
        height: 32px;
        --wc-icon-size: 22px;
        font-size: 14px;
        border-radius: 3px;
      }

      .avatar {
        display: flex;
        align-items: center;
        justify-content: center;
        width: 100%;
        height: 100%;
        padding: 4px;
        border-radius: inherit;
        text-align: center;
        background: var(--wc-avatar-color, var(--color-grey-3));
        color: #fff;
        -webkit-user-select: none;
        user-select: none;

        img {
          width: 100%;
          height: 100%;
          border-radius: inherit;
          -webkit-user-drag: none;
        }
      }

      :host([src]) {
        .avatar {
          padding: 0;
        }
      }

      :host([circle]) {
        border-radius: 50%;
      }
    `,
    // 尺寸
    css`
      :host([size='small']) {
        width: 24px;
        height: 24px;
        font-size: 12px;
        --wc-icon-size: 14px;
      }
    `
  ]

  mounted() {
    if (this.textContent.trim().length > 4) {
      this.textContent = this.textContent.trim().slice(0, 4)
    }
  }

  render() {
    return html`
      <main class="avatar">
        ${this.src
          ? html`<img src=${this.src} />`
          : html`<slot><wc-icon name="user"></wc-icon></slot>`}
      </main>
    `
  }
}

Avatar.reg('avatar')
